@@ -9,7 +9,7 @@ use Alien::Build::Plugin::Extract::CommandLine;
 use Alien::Build::Plugin::Extract::Directory;
 
 # ABSTRACT: Extraction negotiation plugin
-our $VERSION = '1.69'; # VERSION
+our $VERSION = '1.89'; # VERSION
 
 
 has '+format' => 'tar';
@@ -17,12 +17,12 @@ has '+format' => 'tar';
 sub init
 {
   my($self, $meta) = @_;
-  
+
   my $format = $self->format;
   $format = 'tar.gz'  if $format eq 'tgz';
   $format = 'tar.bz2' if $format eq 'tbz';
   $format = 'tar.xz'  if $format eq 'txz';
-  
+
   my $plugin = $self->pick($format);
   $meta->apply_plugin($plugin, format => $format);
   $self;
@@ -32,7 +32,7 @@ sub init
 sub pick
 {
   my(undef, $format) = @_;
-  
+
   if($format =~ /^tar(\.(gz|bz2))?$/)
   {
     if(Alien::Build::Plugin::Extract::ArchiveTar->available($format))
@@ -51,7 +51,7 @@ sub pick
     {
       return 'Extract::ArchiveZip';
     }
-    
+
     # If it isn't available, then use the command-line unzip.  Alien::unzip will be used
     # as necessary in environments where it isn't already installed.
     else
@@ -87,7 +87,7 @@ Alien::Build::Plugin::Extract::Negotiate - Extraction negotiation plugin
 
 =head1 VERSION
 
-version 1.69
+version 1.89
 
 =head1 SYNOPSIS
 
@@ -98,7 +98,7 @@ version 1.69
 
 =head1 DESCRIPTION
 
-This is a negotiator plugin for extracting packages downloaded from the internet. 
+This is a negotiator plugin for extracting packages downloaded from the internet.
 This plugin picks the best Extract plugin to do the actual work.  Which plugins are
 picked depend on the properties you specify, your platform and environment.  It is
 usually preferable to use a negotiator plugin rather than using a specific Extract
@@ -131,7 +131,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey
+Roy Storey (KIWIROY)
 
 Ilya Pavlov
 
