@@ -6,7 +6,7 @@ use Alien::Build::Plugin;
 use Path::Tiny ();
 
 # ABSTRACT: Convert .pc files into static
-our $VERSION = '1.78'; # VERSION
+our $VERSION = '1.89'; # VERSION
 
 
 has path => undef;
@@ -14,14 +14,14 @@ has path => undef;
 sub _convert
 {
   my($self, $build, $path) = @_;
-  
+
   die "unable to read $path" unless -r $path;
   die "unable to write $path" unless -w $path;
-  
+
   $build->log("converting $path to static");
-  
+
   my %h = map {
-    my($key, $value) = $_ =~ /^(.*?):(.*?)$/;
+    my($key, $value) = /^(.*?):(.*?)$/;
     $value =~ s{^\s+}{};
     $value =~ s{\s+$}{};
     ($key => $value);
@@ -29,15 +29,15 @@ sub _convert
 
   $h{Cflags} = '' unless defined $h{Cflags};
   $h{Libs}   = '' unless defined $h{Libs};
-  
+
   $h{Cflags} .= ' ' . $h{"Cflags.private"} if defined $h{"Cflags.private"};
   $h{Libs}   .= ' ' . $h{"Libs.private"} if defined $h{"Libs.private"};
-  
+
   $h{"Cflags.private"} = '';
   $h{"Libs.private"}  = '';
-  
+
   $path->edit_lines(sub {
-  
+
     if(/^(.*?):/)
     {
       my $key = $1;
@@ -47,7 +47,7 @@ sub _convert
         delete $h{$key};
       }
     }
-  
+
   });
 
   $path->append("$_: $h{$_}\n") foreach keys %h;
@@ -56,7 +56,7 @@ sub _convert
 sub _recurse
 {
   my($self, $build, $dir) = @_;
-  
+
   foreach my $child ($dir->children)
   {
     if(-d $child)
@@ -79,7 +79,7 @@ sub init
   $meta->before_hook(
     gather_share => sub {
       my($build) = @_;
-    
+
       if($self->path)
       {
         $self->_convert($build, Path::Tiny->new($self->path)->absolute);
@@ -88,7 +88,7 @@ sub init
       {
         $self->_recurse($build, Path::Tiny->new(".")->absolute);
       }
-    
+
     },
   );
 }
@@ -107,7 +107,7 @@ Alien::Build::Plugin::PkgConfig::MakeStatic - Convert .pc files into static
 
 =head1 VERSION
 
-version 1.78
+version 1.89
 
 =head1 SYNOPSIS
 
