@@ -6,11 +6,11 @@ use 5.008001;
 use base qw( Exporter);
 use Path::Tiny qw( path );
 use Carp qw( croak );
-use File::Temp qw( tempdir );
 use Test2::API qw( context run_subtest );
 use Capture::Tiny qw( capture_merged );
 use Alien::Build::Util qw( _mirror );
-use File::chdir;
+use List::Util 1.33 qw( any );
+use Alien::Build::Temp;
 
 our @EXPORT = qw(
   alienfile
@@ -29,7 +29,7 @@ our @EXPORT = qw(
 );
 
 # ABSTRACT: Tools for testing Alien::Build + alienfile
-our $VERSION = '1.79'; # VERSION
+our $VERSION = '1.89'; # VERSION
 
 
 my $build;
@@ -50,12 +50,13 @@ sub alienfile
   my %args = @_ == 0 ? (filename => 'alienfile') : @_ % 2 ? ( source => do { '# line '. $line . ' "' . path($filename)->absolute . qq("\n) . $_[0] }) : @_;
 
   require alienfile;
-  push @alienfile::EXPORT, 'targ' unless grep /^targ$/, @alienfile::EXPORT;
+  push @alienfile::EXPORT, 'targ' unless any { /^targ$/ } @alienfile::EXPORT;
 
+  my $temp = Alien::Build::Temp->newdir;
   my $get_temp_root = do{
     my $root; # may be undef;
     sub {
-      $root ||= Path::Tiny->new(tempdir( CLEANUP => 1, DIR => $CWD ));
+      $root ||= Path::Tiny->new($temp);
 
       if(@_)
       {
@@ -104,7 +105,7 @@ sub alienfile
   $ctx->release;
 
   $build_alienfile = $args{filename};
-  $build_root      = $get_temp_root->();
+  $build_root      = $temp;
   $build
 }
 
@@ -429,7 +430,7 @@ sub alien_build_clean
   my $ctx = context();
   if($build_root)
   {
-    foreach my $child ($build_root->children)
+    foreach my $child (path($build_root)->children)
     {
       next if $child->basename eq 'prefix';
       $ctx->note("clean: rm: $child");
@@ -568,6 +569,8 @@ sub alien_resume_ok
 }
 
 
+my $alien_rc_root;
+
 sub alien_rc
 {
   my($code) = @_;
@@ -578,7 +581,10 @@ sub alien_rc
   my(undef, $filename, $line) = caller;
   my $code2 = "use strict; use warnings;\n" .
               '# line ' . $line . ' "' . path($filename)->absolute . "\n$code";
-  my $rc = path(tempdir( CLEANUP => 1 ), 'rc.pl');
+
+  $alien_rc_root ||= Alien::Build::Temp->newdir;
+
+  my $rc = path($alien_rc_root)->child('rc.pl');
   $rc->spew_utf8($code2);
   $ENV{ALIEN_BUILD_RC} = "$rc";
   return 1;
@@ -600,7 +606,7 @@ sub alien_subtest
   $pass;
 }
 
-delete $ENV{$_} for qw( ALIEN_BUILD_PRELOAD ALIEN_BUILD_POSTLOAD ALIEN_INSTALL_TYPE PKG_CONFIG_PATH );
+delete $ENV{$_} for qw( ALIEN_BUILD_LOG ALIEN_BUILD_PRELOAD ALIEN_BUILD_POSTLOAD ALIEN_INSTALL_TYPE PKG_CONFIG_PATH );
 $ENV{ALIEN_BUILD_RC} = '-';
 
 1;
@@ -617,7 +623,7 @@ Test::Alien::Build - Tools for testing Alien::Build + alienfile
 
 =head1 VERSION
 
-version 1.79
+version 1.89
 
 =head1 SYNOPSIS
 
@@ -627,7 +633,7 @@ version 1.79
  # returns an instance of Alien::Build.
  my $build = alienfile_ok q{
    use alienfile;
-   
+ 
    plugin 'My::Plugin' => (
      foo => 1,
      bar => 'string',
